package gui;

import gui.panels.*;
import gui.states.MousePosState;

import java.awt.Dimension;
import java.awt.Toolkit;
import java.awt.event.ActionEvent;
import java.io.IOException;
import java.util.List;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JOptionPane;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.border.EtchedBorder;

import car.ICar;

import main.CarGui;

public class CarFrame extends JFrame {

	private CarPanel myCarPanel;
	private final ICar myCar;

	private final JTextArea myConsole = new JTextArea("Журнал событий:\n");

	public CarFrame(ICar car, List<MousePosState> carStates,
			MousePosState blinkingLampState) {
		super("Электронная автомобильная сигнализационная система");
		setDefaultCloseOperation(EXIT_ON_CLOSE);

		myCar = car;

		CarGui.getInstance(this);
		myConsole.setEditable(false);

		JButton ignitionButton = new JButton(new AbstractAction(
				"Включить зажигание") {
			private boolean isOn = false;

			public void actionPerformed(ActionEvent e) {
				if (isOn) {
					isOn = false;
					this.putValue(Action.NAME, "Включить зажигание");
				} else {
					isOn = true;
					this.putValue(Action.NAME, "Выключить зажигание");
				}
				myCar.setIgnitionState(isOn);
			}
		});
		ignitionButton.setAlignmentX(JButton.CENTER_ALIGNMENT);
		ignitionButton.setAlignmentY(JButton.CENTER_ALIGNMENT);

		JButton lightShockButton = new JButton(
				new AbstractAction("Слабый удар") {
					public void actionPerformed(ActionEvent e) {
						myCar.setShock(true);
					}
				});
		lightShockButton.setAlignmentX(JButton.CENTER_ALIGNMENT);
		lightShockButton.setAlignmentY(JButton.CENTER_ALIGNMENT);

		JButton shockButton = new JButton(new AbstractAction("Сильный удар") {
			public void actionPerformed(ActionEvent e) {
				myCar.setShock(false);
			}
		});
		shockButton.setAlignmentX(JButton.CENTER_ALIGNMENT);
		shockButton.setAlignmentY(JButton.CENTER_ALIGNMENT);

		Box actionPanel = new Box(BoxLayout.Y_AXIS);
		actionPanel.add(ignitionButton);
		actionPanel.add(lightShockButton);
		actionPanel.add(shockButton);

		Box controlPanel = new Box(BoxLayout.X_AXIS);
		JScrollPane consoleScrollPane = new JScrollPane(myConsole,
				JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED,
				JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
		consoleScrollPane.setAutoscrolls(true);
		controlPanel.add(consoleScrollPane);
		controlPanel.add(Box.createHorizontalStrut(10));
		controlPanel.add(actionPanel);

		controlPanel.setBorder(new EtchedBorder(EtchedBorder.RAISED));

		Box mainPanel = new Box(BoxLayout.Y_AXIS);
		try {
			myCarPanel = new CarPanel(carStates, blinkingLampState);
		} catch (IOException e) {
			JOptionPane.showMessageDialog(this,
					"Cannot load images for car panel!", "Error while loading",
					JOptionPane.ERROR_MESSAGE);
			System.exit(-1);
		}

		mainPanel.add(myCarPanel);
		mainPanel.add(controlPanel);
		add(mainPanel);
		pack();
		setResizable(false);
		Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((screenDim.width - getWidth()) / 2,
				(screenDim.height - getHeight()) / 2);
	}

	public void addToLog(String message) {
		myConsole.append(message + "\n");
	}

	public void blink(int times) {
		myCarPanel.blink(times);
	}

	public void startBlinking() {
		myCarPanel.startBlinking();
	}
}