package gui;

import java.awt.*;

import javax.swing.JOptionPane;

public class SplashWindow extends Window {

	private static SplashWindow instance;
	private Image image;

	private boolean paintCalled = false;

	private SplashWindow(Frame parent, Image image) {
		super(parent);
		this.image = image;

		// Load the image
		MediaTracker mt = new MediaTracker(this);
		mt.addImage(image, 0);
		try {
			mt.waitForID(0);
		} catch (InterruptedException ie) {

		}

		// Abort on failure
		if (mt.isErrorID(0)) {
			setSize(0, 0);
			System.err
					.println("Warning: SplashWindow couldn't load splash image.");
			synchronized (this) {
				paintCalled = true;
				notifyAll();
			}
			return;
		}

		// Center the window on the screen
		int imgWidth = image.getWidth(this);
		int imgHeight = image.getHeight(this);
		setSize(imgWidth, imgHeight);
		Dimension screenDim = Toolkit.getDefaultToolkit().getScreenSize();
		setLocation((screenDim.width - imgWidth) / 2,
				(screenDim.height - imgHeight) / 2);
	}

	public void update(Graphics g) {
		paint(g);
	}

	public void paint(Graphics g) {
		g.drawImage(image, 0, 0, this);
		if (!paintCalled) {
			paintCalled = true;
			synchronized (this) {
				notifyAll();
			}
		}
	}

	public static void splash(Image image) {
		if (instance == null && image != null) {
			Frame f = new Frame();

			instance = new SplashWindow(f, image);
			instance.setAlwaysOnTop(true);
			instance.setVisible(true);
		}
	}

	public static void setOnTop(boolean isOnTop) {
		instance.setAlwaysOnTop(isOnTop);
	}

	public static void disposeSplash() {
		if (instance != null) {
			instance.getOwner().dispose();
			instance = null;
		}
	}

	public static void displayMessage(String message, String title) {
    	if (instance != null) {
    		disposeSplash();
    		JOptionPane.showMessageDialog(instance, message, title, JOptionPane.ERROR_MESSAGE);
    	} else {
    		System.err.println(title + " : " + message);
    	}
    }
}