package gui.panels;

import gui.states.MousePosState;

import javax.imageio.ImageIO;
import javax.swing.*;
import java.awt.*;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import java.awt.event.MouseMotionListener;
import java.io.File;
import java.io.IOException;
import java.util.LinkedList;
import java.util.List;

public class CarPanel extends JPanel {
	private static final String MainBGImage = "main.png";
	
	private final Image myBackgroundImage;
	private final List<MousePosState> myMouseStates;
	private final MousePosState myBlinkingLampState;	
	private Image myDoorPatchImage = ImageIO.read(new File("media/images",
			"doors.png"));
	
	private int myNumDoorsOpen;
	private BlinkerThread myBlinkerThread;
	 
	public CarPanel(List<MousePosState> carStates, MousePosState blinkingLampState) throws IOException {
		myBackgroundImage = ImageIO.read(new File("media/images", MainBGImage));
		myMouseStates = new LinkedList<MousePosState>(carStates);
		myBlinkingLampState = blinkingLampState;
		myDoorPatchImage = gui.states.Transparency.makeColorTransparent(myDoorPatchImage, new Color(200, 20, 200));
		
		MousePosListener positionAdapter = new MousePosListener();
		addMouseListener(positionAdapter);
		addMouseMotionListener(positionAdapter);
		
		new Thread(myBlinkerThread).start();
		
		setPreferredSize(new Dimension(800, 536));
		setMinimumSize(getPreferredSize());
		setMaximumSize(getPreferredSize());
	}

	public void blink(int times) {
		if (myBlinkerThread != null) {
			myBlinkerThread.stop();
		}
		myBlinkerThread = new BlinkerThread(times);
		new Thread(myBlinkerThread).start();
	}

	public void startBlinking() {
		blink(99);
	}

	public void paint(Graphics g) {
		g.drawImage(myBackgroundImage, 0, 0, 800, 536, null);
		for (MousePosState state : myMouseStates) {
			if (state.isActivated())
				state.drawImage(g);
		}
		if (myNumDoorsOpen == 2) {
			getGraphics().drawImage(myDoorPatchImage, 491, 133,
					myDoorPatchImage.getWidth(null),
					myDoorPatchImage.getHeight(null), null);
		}
	}

	private class BlinkerThread implements Runnable {
		private int myCounter;

		public BlinkerThread(int times) {
			myCounter = times;
		}

		public void stop() {
			myCounter = 0;
		}

		public void run() {
			while (myCounter > 0) {
				myBlinkingLampState.react();
				myBlinkingLampState.animate(getGraphics());
				myBlinkingLampState.react();
				myBlinkingLampState.animate(getGraphics());
				myCounter--;
			}
		}
	}

	private class MousePosListener extends MouseAdapter implements
			MouseMotionListener {

		public void mouseClicked(MouseEvent e) {
			for (MousePosState state : myMouseStates) {
				if (state.isActiveOver(e.getPoint())) {
					state.react();
					if (state.isDoor() && state.isActivated())
						myNumDoorsOpen++;
					if ((myNumDoorsOpen == 2) && (state.isDoor())) {
						state.drawImage(getGraphics());
					} else {
						Graphics g = getGraphics();
						state.animate(g);
					}
					break;
				}
			}
			myNumDoorsOpen = 0;
			for (MousePosState state : myMouseStates) {
				if (state.isActivated()) {
					if (state.isDoor())
						myNumDoorsOpen++;
					state.drawImage(getGraphics());
				}
			}
			if (myNumDoorsOpen == 2) {
				getGraphics().drawImage(myDoorPatchImage, 491, 133,
						myDoorPatchImage.getWidth(null),
						myDoorPatchImage.getHeight(null), null);
			}
		}

		public void mouseMoved(MouseEvent e) {
			setCursor(Cursor.getPredefinedCursor(Cursor.DEFAULT_CURSOR));
			for (MousePosState state : myMouseStates) {
				if (state.isActiveOver(e.getPoint())) {
					setCursor(Cursor.getPredefinedCursor(Cursor.HAND_CURSOR));
				}
			}
		}

		public void mouseDragged(MouseEvent e) {
			// Just to be compatible with Java 1.5
		}
	}
}