package gui.panels;

import gui.IRemoteGui;

import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;
import java.awt.Image;
import java.io.File;
import java.io.IOException;

import javax.imageio.ImageIO;
import javax.swing.JPanel;

import main.CarGui;

import gui.states.Transparency;

public class RemoteControlBackPanel extends JPanel implements IRemoteGui {
	private static final String PATH = "media/images/remote/";
	private static final String MainBGImage = "remoteBack.png";
	private static final String navigationImage = "navigation.png";

	private static final String exitMode = "exitMode.png";

	private static final String mainMenu = "mainMenu.png";
	private static final String silentMenu = "silentMenu.png";
	private static final String sensorMenu = "sensorMenu.png";

	private static final String silentMode = "silentMode.png";
	private static final String sensorMode = "sensorMode.png";

	private static final String enableMode = "enableMode.png";
	private static final String disableMode = "disableMode.png";

	private static final String lowMode = "lowMode.png";
	private static final String middleMode = "middleMode.png";
	private static final String highMode = "highMode.png";

	private static final String lockON = "lockON.png";
	private static final String lockOFF = "lockOFF.png";
	private static final String soundON = "soundON.png";
	private static final String soundOFF = "soundOFF.png";
	private static final String kickON = "kickON.png";
	private static final String kickOFF = "kickOFF.png";
	private static final String doorsON = "doorsON.png";
	private static final String doorsOFF = "doorsOFF.png";

	private final Image myBackgroundImage = ImageIO.read(new File(PATH,
			MainBGImage));
	private final Image myNavigationImage = Transparency.makeColorTransparent(
			ImageIO.read(new File(PATH, navigationImage)), new Color(200, 20,
					200));

	private final Image mainMenuImage = ImageIO.read(new File(PATH, mainMenu));
	private final Image silentMenuImage = ImageIO.read(new File(PATH,
			silentMenu));
	private final Image sensorMenuImage = ImageIO.read(new File(PATH,
			sensorMenu));
	private final Image[] myTitles = new Image[] { mainMenuImage,
			silentMenuImage, sensorMenuImage };

	private final Image silentModeImage = ImageIO.read(new File(PATH
			+ "/mainMenu", silentMode));
	private final Image sensorModeImage = ImageIO.read(new File(PATH
			+ "/mainMenu", sensorMode));
	private final Image enableModeImage = ImageIO.read(new File(PATH
			+ "/silentMenu", enableMode));
	private final Image disableModeImage = ImageIO.read(new File(PATH
			+ "/silentMenu", disableMode));
	private final Image lowModeImage = ImageIO.read(new File(PATH
			+ "/sensorMenu", lowMode));
	private final Image middleModeImage = ImageIO.read(new File(PATH
			+ "/sensorMenu", middleMode));
	private final Image highModeImage = ImageIO.read(new File(PATH
			+ "/sensorMenu", highMode));
	private final Image exitModeImage = ImageIO.read(new File(PATH, exitMode));

	private final Image[] myItems = new Image[] { silentModeImage,
			sensorModeImage, enableModeImage, disableModeImage, lowModeImage,
			middleModeImage, highModeImage, exitModeImage };

	private final Image lockONImage = ImageIO.read(new File(PATH + "/picts",
			lockON));
	private final Image lockOFFImage = ImageIO.read(new File(PATH + "/picts",
			lockOFF));
	private final Image soundONImage = ImageIO.read(new File(PATH + "/picts",
			soundON));
	private final Image soundOFFImage = ImageIO.read(new File(PATH + "/picts",
			soundOFF));
	private final Image kickONImage = ImageIO.read(new File(PATH + "/picts",
			kickON));
	private final Image kickOFFImage = ImageIO.read(new File(PATH + "/picts",
			kickOFF));
	private final Image doorsONImage = ImageIO.read(new File(PATH + "/picts",
			doorsON));
	private final Image doorsOFFImage = ImageIO.read(new File(PATH + "/picts",
			doorsOFF));

	private boolean myLockIsLocked = false;
	private boolean mySoundIsOn = true;
	private boolean myShockIsOn = false;
	private boolean myDoorIsOpened = true;
	private boolean myMenuState = false;
	private int myCurrentTitle = 0;
	private int myCurrentItem = 0;

	public RemoteControlBackPanel() throws IOException {
		setPreferredSize(new Dimension(361, 200));
		setMinimumSize(getPreferredSize());
		setMaximumSize(getPreferredSize());

		CarGui.setRemote(this);
	}

	public void paint(Graphics g) {
		if (myMenuState) {
			g.drawImage(myNavigationImage, 0, 0, 361, 200, null);
			paintTitle(g);
			paintItem(g);
		} else {
			g.drawImage(myBackgroundImage, 0, 0, 361, 200, null);
			paintIcons(g);
		}
	}

	private void paintTitle(Graphics g) {
		g
				.drawImage(myTitles[myCurrentTitle], 68, 27,
						myTitles[myCurrentTitle].getWidth(null),
						myTitles[myCurrentTitle].getHeight(null), null);
	}

	private void paintItem(Graphics g) {
		g.drawImage(myItems[myCurrentItem], 71, 58, myItems[myCurrentItem]
				.getWidth(null), myItems[myCurrentItem].getHeight(null), null);
	}

	private void paintIcons(Graphics g) {
		if (myLockIsLocked) {
			g.drawImage(lockONImage, 96, 62, lockONImage.getWidth(null),
					lockONImage.getHeight(null), null);
		} else {
			g.drawImage(lockOFFImage, 96, 62, lockOFFImage.getWidth(null),
					lockOFFImage.getHeight(null), null);
		}
		if (mySoundIsOn) {
			g.drawImage(soundONImage, 35, 58, soundONImage.getWidth(null),
					soundONImage.getHeight(null), null);
		} else {
			g.drawImage(soundOFFImage, 35, 58, soundOFFImage.getWidth(null),
					soundOFFImage.getHeight(null), null);
		}
		if (myShockIsOn) {
			g.drawImage(kickONImage, 154, 43, kickONImage.getWidth(null),
					kickONImage.getHeight(null), null);
		} else {
			g.drawImage(kickOFFImage, 154, 43, kickOFFImage.getWidth(null),
					kickOFFImage.getHeight(null), null);
		}
		if (myDoorIsOpened) {
			g.drawImage(doorsONImage, 200, 30, doorsONImage.getWidth(null),
					doorsONImage.getHeight(null), null);
		} else {
			g.drawImage(doorsOFFImage, 200, 30, doorsOFFImage.getWidth(null),
					doorsOFFImage.getHeight(null), null);
		}
	}

	public void setMode(boolean isMenu) {
		myMenuState = isMenu;
		repaint();
	}

	public void setMenuItem(int itemNum) {
		myCurrentItem = itemNum;
		repaint();
	}

	public void setMenuTitle(int titleNum) {
		myCurrentTitle = titleNum;
		repaint();
	}

	public void setLockState(boolean isLocked) {
		myLockIsLocked = isLocked;
		repaint();
	}

	public void setSoundState(boolean isOn) {
		mySoundIsOn = isOn;
		repaint();
	}

	public void setShockState(boolean isShocked) {
		myShockIsOn = isShocked;
		repaint();
	}

	public void setDoorState(boolean isOpened) {
		myDoorIsOpened = isOpened;
		repaint();
	}
}
