package main;

import java.awt.Toolkit;
import java.io.IOException;

import gui.CarFrame;
import gui.RemoteFrame;
import gui.SplashWindow;
import gui.states.StatesFactory;

import com.evelopers.common.exception.CommonException;
import com.evelopers.unimod.runtime.ModelEngine;

import car.*;
import remote.*;

public class Main {

	private static final ICar myCar = new CarImpl();
	private static final IRemoteControl myRemote = new RemoteImpl();
	private static final StatesFactory myStatesFactory = new StatesFactory(
			myCar, myRemote);

	private static ModelEngine myModelEngine;

	private void run() throws CommonException {
		myModelEngine = Model1EventProcessor.createModelEngine(true);
		myModelEngine.start();
	}

	/**
	 * @param args
	 *            ignored
	 */
	public static void main(String[] args) {
		try {
			SplashWindow.splash(Toolkit.getDefaultToolkit().createImage(
					"media/images/splash.png"));
			CarFrame carFrame = new CarFrame(myCar, myStatesFactory
					.getCarStates(), myStatesFactory.getBlinkingLampState());
			RemoteFrame remoteFrame = new RemoteFrame(myStatesFactory
					.getRemoteStates());
			new Main().run();
			SplashWindow.disposeSplash();
			Thread.sleep(100);
			carFrame.setVisible(true);
			remoteFrame.setVisible(true);
		} catch (IOException e) {
			SplashWindow.displayMessage("Unable to load all images",
					"Error while loading");
		} catch (InterruptedException e) {
			System.err.println(e);
		} catch (CommonException e) {
			System.err.println("Error happened: " + e);
			System.exit(239);
		} finally {
			SplashWindow.disposeSplash();
		}
	}
}
